@@ -1,5 +1,6 @@
 var NAVTREEINDEX16 =
 {
+"page_spa_design.html#autotoc_md130":[9,4,0,2],
 "page_spa_plugins.html":[9,5],
 "page_spa_plugins.html#autotoc_md115":[9,5,0],
 "page_spa_plugins.html#autotoc_md116":[9,5,1],
@@ -248,6 +249,5 @@ var NAVTREEINDEX16 =
 "structpw__core__methods.html#af1831e5a0a805bf3ed47e48dbd09ee3a":[10,4,4,3,0],
 "structpw__data__loop.html":[10,5,11,2],
 "structpw__data__loop__events.html":[10,5,11,1],
-"structpw__data__loop__events.html#a19c5624deda8fb2d4fd452bf6ba6c3b8":[10,5,11,1,0],
-"structpw__data__loop__events.html#a5ee1e79472b7ab5aab28d40df7a1db0b":[10,5,11,1,1]
+"structpw__data__loop__events.html#a19c5624deda8fb2d4fd452bf6ba6c3b8":[10,5,11,1,0]
 };
