@@ -1,5 +1,6 @@
 var NAVTREEINDEX18 =
 {
+"structpw__memchunk.html":[10,6,5,6],
 "structpw__memmap.html":[10,6,5,3],
 "structpw__memmap.html#a2a254ea08d19704537d73b68ef548a12":[10,6,5,3,3],
 "structpw__memmap.html#a586c7656b932f4c50d0efb007bae6c64":[10,6,5,3,1],
@@ -248,6 +249,5 @@ var NAVTREEINDEX18 =
 "structspa__audio__aec__methods.html#aadf3db584c3062de5a2af134e6d7014d":[11,0,140,3],
 "structspa__audio__aec__methods.html#af6f30eee3a6af553b3e6ef83f850a691":[11,0,140,0],
 "structspa__audio__aec__methods.html#af75957ae10a92bb2253df67aa6eca97f":[11,0,140,9],
-"structspa__audio__aec__methods.html#af7b0dbc68aecaab0c278bc95a9d37503":[11,0,140,2],
-"structspa__audio__info.html":[10,8,7,20]
+"structspa__audio__aec__methods.html#af7b0dbc68aecaab0c278bc95a9d37503":[11,0,140,2]
 };
