@@ -1,5 +1,6 @@
 var NAVTREEINDEX19 =
 {
+"structspa__audio__info.html":[10,8,7,20],
 "structspa__audio__info.html#a07b9f000b469ff8389b93290a5a06b2b":[10,8,7,20,5],
 "structspa__audio__info.html#a1831d447b0446ff947e879f2de34d410":[10,8,7,20,3],
 "structspa__audio__info.html#a1c0fd971fb059d844722a21feeb3de59":[10,8,7,20,6],
@@ -248,6 +249,5 @@ var NAVTREEINDEX19 =
 "structspa__io__segment.html":[10,8,6,15],
 "structspa__io__segment.html#a6b7f7b35362210bbb0548ce4ab463e12":[10,8,6,15,2],
 "structspa__io__segment.html#a6ba7bf8b5ba9725546b59b1918f49cc7":[10,8,6,15,1],
-"structspa__io__segment.html#aa0c906a4de1d90ec5042826b14742301":[10,8,6,15,4],
-"structspa__io__segment.html#ab725d4cd7f8cb1a44abe185ac504fd1c":[10,8,6,15,3]
+"structspa__io__segment.html#aa0c906a4de1d90ec5042826b14742301":[10,8,6,15,4]
 };
