@@ -1,5 +1,6 @@
 var NAVTREEINDEX20 =
 {
+"structspa__io__segment.html#ab725d4cd7f8cb1a44abe185ac504fd1c":[10,8,6,15,3],
 "structspa__io__segment.html#ac4988f1d377a80a859eb45771f3317fb":[10,8,6,15,6],
 "structspa__io__segment.html#ad525d9a6f0185e329abc7e89fe394cfd":[10,8,6,15,5],
 "structspa__io__segment.html#af9ec3a1565e77b1ad781376b758b58c3":[10,8,6,15,0],
@@ -248,6 +249,5 @@ var NAVTREEINDEX20 =
 "structspa__pod__int.html#ab0f590008a307cc732cba65d45b62299":[10,8,0,22,1],
 "structspa__pod__long.html":[10,8,0,23],
 "structspa__pod__long.html#a6a21d96d55e7dcbb392d1058411ec861":[10,8,0,23,1],
-"structspa__pod__long.html#a8b04bfc3d7876362001efa4f3585f186":[10,8,0,23,0],
-"structspa__pod__object.html":[10,8,0,37]
+"structspa__pod__long.html#a8b04bfc3d7876362001efa4f3585f186":[10,8,0,23,0]
 };
